You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@xerces.apache.org by mr...@apache.org on 2006/06/16 21:18:45 UTC

svn commit: r414889 - in /xerces/java/trunk/tools: bin/xjavac.jar src/XJavac.java

Author: mrglavas
Date: Fri Jun 16 12:18:45 2006
New Revision: 414889

URL: http://svn.apache.org/viewvc?rev=414889&view=rev
Log:
Fixing JIRA Bug #1167: 
http://issues.apache.org/jira/browse/XERCESJ-1167

Allow Xerces to built with Sable VM and Kaffe.

Modified:
    xerces/java/trunk/tools/bin/xjavac.jar
    xerces/java/trunk/tools/src/XJavac.java

Modified: xerces/java/trunk/tools/bin/xjavac.jar
URL: http://svn.apache.org/viewvc/xerces/java/trunk/tools/bin/xjavac.jar?rev=414889&r1=414888&r2=414889&view=diff
==============================================================================
Binary files - no diff available.

Modified: xerces/java/trunk/tools/src/XJavac.java
URL: http://svn.apache.org/viewvc/xerces/java/trunk/tools/src/XJavac.java?rev=414889&r1=414888&r2=414889&view=diff
==============================================================================
--- xerces/java/trunk/tools/src/XJavac.java (original)
+++ xerces/java/trunk/tools/src/XJavac.java Fri Jun 16 12:18:45 2006
@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2005 The Apache Software Foundation.
+ * Copyright 2001-2006 The Apache Software Foundation.
  * 
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -61,11 +61,13 @@
                 setBootclasspath(createIBMJDKBootclasspath());
             }
             // need to do special things for Sun too and also
             // for Apple, HP and Blackdown: a Linux port of Sun Java
             else if( (vendor.indexOf("SUN") >= 0) || 
                      (vendor.indexOf("BLACKDOWN") >= 0) || 
                      (vendor.indexOf("APPLE") >= 0) ||
-                     (vendor.indexOf("HEWLETT-PACKARD") >= 0)) {
+                     (vendor.indexOf("HEWLETT-PACKARD") >= 0) ||
+                     (vendor.indexOf("KAFFE") >= 0) ||
+                     (vendor.indexOf("SABLE") >= 0)) {
                 // we're on an SUN 1.4 or higher; fiddle with the bootclasspath.
                 // since we can't eviscerate XML-related info here,
                 // we must use the classpath



---------------------------------------------------------------------
@@ -61,11 +61,13 @@
             }
             // need to do special things for Sun too and also
-            // for Apple, HP and Blackdown: a Linux port of Sun Java
+            // for Apple, HP, SableVM, Kaffe and Blackdown: a Linux port of Sun Java
             else if( (vendor.indexOf("SUN") >= 0) || 
                      (vendor.indexOf("BLACKDOWN") >= 0) || 
To unsubscribe, e-mail: commits-unsubscribe@xerces.apache.org
For additional commands, e-mail: commits-help@xerces.apache.org